aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Target/SparcV9
diff options
context:
space:
mode:
authorBrian Gaeke <gaeke@uiuc.edu>2003-09-18 17:37:46 +0000
committerBrian Gaeke <gaeke@uiuc.edu>2003-09-18 17:37:46 +0000
commit79c980399eac57b9472a12702a313c9ab9c51e00 (patch)
tree8937b954af7fc23d319cc17bb1738b1b9efa96fd /lib/Target/SparcV9
parentb92c5c0c15c49346eec3fd6df10afb9800eb10a9 (diff)
downloadexternal_llvm-79c980399eac57b9472a12702a313c9ab9c51e00.zip
external_llvm-79c980399eac57b9472a12702a313c9ab9c51e00.tar.gz
external_llvm-79c980399eac57b9472a12702a313c9ab9c51e00.tar.bz2
Fix a typo in Sparc.cpp.
Update names of some pass creator fns in addPassesToEmitAssembly(). FunctionInfo is gone. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@8599 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/SparcV9')
-rw-r--r--lib/Target/SparcV9/SparcV9Internals.h6
-rw-r--r--lib/Target/SparcV9/SparcV9TargetMachine.cpp10
2 files changed, 6 insertions, 10 deletions
diff --git a/lib/Target/SparcV9/SparcV9TargetMachine.cpp b/lib/Target/SparcV9/SparcV9TargetMachine.cpp
index cfb753a..7b06644 100644
--- a/lib/Target/SparcV9/SparcV9TargetMachine.cpp
+++ b/lib/Target/SparcV9/SparcV9TargetMachine.cpp
@@ -180,7 +180,7 @@ bool UltraSparc::addPassesToEmitAssembly(PassManager &PM, std::ostream &Out)
// If LLVM dumping after transformations is requested, add it to the pipeline
if (DumpInput)
- PM.add(new PrintFunctionPass("Input code to instsr. selection:\n",
+ PM.add(new PrintFunctionPass("Input code to instr. selection:\n",
&std::cerr));
PM.add(createInstructionSelectionPass(*this));
@@ -196,7 +196,7 @@ bool UltraSparc::addPassesToEmitAssembly(PassManager &PM, std::ostream &Out)
PM.add(createPeepholeOptsPass(*this));
if (EmitMappingInfo)
- PM.add(getMappingInfoCollector(Out));
+ PM.add(getMappingInfoAsmPrinterPass(Out));
// Output assembly language to the .s file. Assembly emission is split into
// two parts: Function output and Global value output. This is because
@@ -211,10 +211,8 @@ bool UltraSparc::addPassesToEmitAssembly(PassManager &PM, std::ostream &Out)
PM.add(getModuleAsmPrinterPass(Out));
// Emit bytecode to the assembly file into its special section next
- if (EmitMappingInfo) {
- PM.add(getEmitBytecodeToAsmPass(Out));
- PM.add(getFunctionInfo(Out));
- }
+ if (EmitMappingInfo)
+ PM.add(getBytecodeAsmPrinterPass(Out));
return false;
}
diff --git a/lib/Target/SparcV9/SparcV9Internals.h b/lib/Target/SparcV9/SparcV9Internals.h
index 35a649c..79bfde7 100644
--- a/lib/Target/SparcV9/SparcV9Internals.h
+++ b/lib/Target/SparcV9/SparcV9Internals.h
@@ -687,10 +687,8 @@ public:
// getModuleAsmPrinterPass - Writes generated machine code to assembly file.
Pass* getModuleAsmPrinterPass(std::ostream &Out);
- // getEmitBytecodeToAsmPass - Emits final LLVM bytecode to assembly file.
- Pass* getEmitBytecodeToAsmPass(std::ostream &Out);
+ // getBytecodeAsmPrinterPass - Emits final LLVM bytecode to assembly file.
+ Pass* getBytecodeAsmPrinterPass(std::ostream &Out);
};
-Pass *getFunctionInfo(std::ostream &out);
-
#endif